<img title="dicaso suite logo" src="logos/dicaso-suite.svg" width="200">

PYthon CAviar Solutions SOftware Suite

## Components

Pycassos offers a graphical user interface to all bioinformatics components
developed by Digital Caviar Solutions.

- genairics: raw data analysis
- bidali: advanced processing and biological inference
- pyni: network inference package
- leopard: lab reporting package

## Acknowledgments

### Open source projects

This project would not have been possible if it could not rely on the work of many
other open source projects. It would be too many to list here, but they can be found
by looking at the `setup.py` files of the different dicaso components.

### dicaso development

#### Software engineers

- Christophe Van Neste, PhD (principal software engineer)
- pyni:
  - Lieven Verbeke, PhD

#### Beta testers

- genairics:
  - Bieke Decaesteker
  - Jolien De Wyn
- bidali:
  - Jolien Dewyn
  - Carolina Nunes
- pyni:
  - Carolina Nunes

#### Funding agencies

- [Ghent University](https://www.ugent.be/)
- [FWO](http://www.fwo.be/)

<table>
<tr>
<td><img title="FWO logo" src="logos/ugent_logo_web.png" width="200"></td>
<td><img title="FWO logo" src="logos/fwo_logo_web.png" width="200"></td>
</tr>
</table>


